@@ -406,7 +406,7 @@ def plot_2D_Data(
     if is_fft:
 
         if thresh is None:
-            if self.normalizations is not None and "ref" in self.normalizations.keys():
+            if self.normalizations is not None and "ref" in self.normalizations:
                 thresh = self.normalizations["ref"]
             else:
                 thresh = 0.02
