@@ -8,5 +8,10 @@ from SciDataTool.Classes.DataND import DataND
 from SciDataTool.Classes.RequestedAxis import RequestedAxis
 from SciDataTool.Classes.VectorField import VectorField
 from SciDataTool.Classes.DataPattern import DataPattern
+from SciDataTool.Classes.Norm_affine import Norm_affine
+from SciDataTool.Classes.Norm_func import Norm_func
+from SciDataTool.Classes.Norm_vector import Norm_vector
+from SciDataTool.Classes.Norm_indices import Norm_indices
+from SciDataTool.Classes.Norm_ref import Norm_ref
 
-__version__ = "1.4.9"
+__version__ = "1.4.10"
